@@ -629,18 +629,23 @@ def algoinfo(maadstoken,maads_rest_url,pkey,username='',passw='',company='',emai
     return msg
 
 def nlpgeosentiment(maadstoken,maads_rest_url,lat,long,radius,searchterms,numtweets=50,wordcount=300,username='',passw='',company='',email=''):
-    files = {'mode':'nlpgeosentiment',        
-        'lat': lat,
-        'long': long,
-        'radius': radius,
-        'searchterms': searchterms,
-        'numtweets': numtweets,
-        'wordcount': wordcount,             
-        'maadstoken':maadstoken
-      }
 
-    r = requests.post(maads_rest_url, files)
-    msg = r.text
+    if len(searchterms)>0:
+        searchterms=searchterms.replace(","," ")
+        files = {'mode':'nlpgeosentiment',        
+            'lat': lat,
+            'long': long,
+            'radius': radius,
+            'searchterms': searchterms,
+            'numtweets': numtweets,
+            'wordcount': wordcount,             
+            'maadstoken':maadstoken
+          }
+
+        r = requests.post(maads_rest_url, files)
+        msg = r.text
+    else:
+       return "ERROR: Enter search terms" 
    
     return msg
 
